@@ -274,4 +274,6 @@ TASKS_TO_SHARE_WITH_SPOKES = [
     "CopyIntoSpokeLocalPortfolioTask",
     "GetPortfolioByPortfolioName",
     "SearchProductsAsAdminTask",
+    "SharePortfolioViaOrgsTask",
+    "SharePortfolioTask",
 ]
