@@ -1,3 +1,6 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import luigi
 
 from servicecatalog_puppet import config
@@ -31,7 +34,7 @@ class GeneratePoliciesTemplate(tasks.PuppetTask):
         rendered = config.env.get_template("policies.template.yaml.j2").render(
             sharing_policies=self.sharing_policies,
             VERSION=constants.VERSION,
-            HOME_REGION=self.region,
+            HOME_REGION=constants.HOME_REGION,
         )
         with self.output().open("w") as output_file:
             output_file.write(rendered)
